@@ -221,9 +221,10 @@ adjust_spec(ImageInput* in, ImageOutput* out, const ImageSpec& inspec,
     if (outspec.nchannels != inspec.nchannels)
         nocopy = true;
 
-    outspec.attribute("oiio:Gamma", gammaval);
+    if (gammaval != 1.0f)
+        outspec.attribute("oiio:Gamma", gammaval);
     if (sRGB) {
-        outspec.set_colorspace("sRGB");
+        outspec.set_colorspace("srgb_rec709_scene");
         if (!strcmp(in->format_name(), "jpeg")
             || outspec.find_attribute("Exif:ColorSpace"))
             outspec.attribute("Exif:ColorSpace", 1);
